searchNodes=[{"ref":"SqlMembershipProvider.Membership.html","title":"SqlMembershipProvider.Membership","type":"module","doc":"Struct for representing a user&#39;s membership to an application and their authentication information."},{"ref":"SqlMembershipProvider.Membership.html#find_by_user_id/2","title":"SqlMembershipProvider.Membership.find_by_user_id/2","type":"function","doc":"Fetch a membership by user id."},{"ref":"SqlMembershipProvider.Membership.html#is_password_valid?/2","title":"SqlMembershipProvider.Membership.is_password_valid?/2","type":"function","doc":"Check if a plaintext password matches a user&#39;s hashed password."},{"ref":"SqlMembershipProvider.Membership.html#t:t/0","title":"SqlMembershipProvider.Membership.t/0","type":"type","doc":""},{"ref":"SqlMembershipProvider.Profile.html","title":"SqlMembershipProvider.Profile","type":"module","doc":"Struct for representing a user&#39;s profile information that may contain arbitrary properties"},{"ref":"SqlMembershipProvider.Profile.html#find_by_user_id/2","title":"SqlMembershipProvider.Profile.find_by_user_id/2","type":"function","doc":"Fetch a profile by user id."},{"ref":"SqlMembershipProvider.Profile.html#properties/1","title":"SqlMembershipProvider.Profile.properties/1","type":"function","doc":"Parse a profile&#39;s property fields into a map."},{"ref":"SqlMembershipProvider.Profile.html#t:t/0","title":"SqlMembershipProvider.Profile.t/0","type":"type","doc":""},{"ref":"SqlMembershipProvider.Role.html","title":"SqlMembershipProvider.Role","type":"module","doc":"Struct for representing a security role that a user may assume"},{"ref":"SqlMembershipProvider.Role.html#find_by_user_id/2","title":"SqlMembershipProvider.Role.find_by_user_id/2","type":"function","doc":"Fetch all roles that a user belongs to."},{"ref":"SqlMembershipProvider.Role.html#t:t/0","title":"SqlMembershipProvider.Role.t/0","type":"type","doc":""},{"ref":"SqlMembershipProvider.TdsUtils.html","title":"SqlMembershipProvider.TdsUtils","type":"module","doc":"Utility functions for converting Tds.Result into custom structs. Usually used like: result |&gt; result_to_map() |&gt; stringify_uuids([&quot;user_id&quot;]) |&gt; to_struct(__MODULE__)"},{"ref":"SqlMembershipProvider.TdsUtils.html#result_to_map/1","title":"SqlMembershipProvider.TdsUtils.result_to_map/1","type":"function","doc":"Convert a Tds.Result into a list of maps. Tds.Result stores values as a list of rows containing a list of column values. Having this stored as a map lets you retrieve a column&#39;s value by it&#39;s column name."},{"ref":"SqlMembershipProvider.TdsUtils.html#stringify_uuids/2","title":"SqlMembershipProvider.TdsUtils.stringify_uuids/2","type":"function","doc":"Convert UUID columns from Microsoft&#39;s mixed-endian format to little-endian format."},{"ref":"SqlMembershipProvider.TdsUtils.html#to_struct/2","title":"SqlMembershipProvider.TdsUtils.to_struct/2","type":"function","doc":"Convert a map into a struct Taken from José on elixir-lang-talk"},{"ref":"SqlMembershipProvider.UnsupportedPasswordFormatError.html","title":"SqlMembershipProvider.UnsupportedPasswordFormatError","type":"exception","doc":""},{"ref":"SqlMembershipProvider.User.html","title":"SqlMembershipProvider.User","type":"module","doc":"Struct for representing a user."},{"ref":"SqlMembershipProvider.User.html#find_by_user_name/2","title":"SqlMembershipProvider.User.find_by_user_name/2","type":"function","doc":"Fetch a user by case-insensitive username."},{"ref":"SqlMembershipProvider.User.html#t:t/0","title":"SqlMembershipProvider.User.t/0","type":"type","doc":""},{"ref":"readme.html","title":"SqlMembershipProvider","type":"extras","doc":"SqlMembershipProvider Read and authenticate against ASP.NET Membership Microsoft SQL Server databases. Do you have an ASP.NET app that uses the built-in Membership Provider that stores users, passwords, roles, and profiles in a Microsoft SQL Server database? This library lets your Elixir code talk to a Membership Provider database to lookup users, their profile information roles they belong to, and authenticate their passwords. This library uses Tds to connect to a Microsoft SQL Server database."},{"ref":"readme.html#usage","title":"SqlMembershipProvider - Usage","type":"extras","doc":"iex(1)&gt; {:ok, pid} = Tds.start_link(hostname: &quot;localhost&quot;, username: &quot;&quot;, password: &quot;&quot;, database: &quot;&quot;, port: 1433) {:ok, #PID&lt;0.236.0&gt;} iex(2)&gt; user = SqlMembershipProvider.User.find_by_user_name(pid, &quot;JohnDoe&quot;) %SqlMembershipProvider.User{ ... } iex(3)&gt; membership = SqlMembershipProvider.Membership.find_by_user_id(pid, user.user_id) %SqlMembershipProvider.Membership{ ... } iex(4)&gt; SqlMembershipProvider.Membership.is_password_valid?(membership, &quot;password!&quot;) true iex(5)&gt; profile = SqlMembershipProvider.Profile.find_by_user_id(pid, user.user_id) %SqlMembershipProvider.Profile{ ... } iex(6)&gt; SqlMembershipProvider.Profile.properties(profile) %{ &quot;FirstName&quot; =&gt; &quot;John&quot;, &quot;LastName&quot; =&gt; &quot;Doe&quot;, ... } iex(7)&gt; roles = SqlMembershipProvider.Role.find_by_user_id(pid, user.user_id) [ %SqlMembershipProvider.Role{ role_name: &quot;Administrators&quot;, ... } ]"},{"ref":"readme.html#running-tests","title":"SqlMembershipProvider - Running Tests","type":"extras","doc":"Clone the repo and fetch its dependencies: $ git clone https://gitlab.com/horse-racing-labs/sql_membership_provider.git $ cd sql_membership_provider $ mix deps.get Docker Compose is required to run a sample SQL Server database to run integration tests against. $ docker-compose up $ ./setup-test-database.sh $ mix test"},{"ref":"readme.html#future-work","title":"SqlMembershipProvider - Future Work","type":"extras","doc":"Once Tds works with Ecto 3.x, this will migrate to using Ecto."},{"ref":"readme.html#help-wanted","title":"SqlMembershipProvider - Help Wanted","type":"extras","doc":"Only the SHA1 password format is supported. Support should be added for the remaining password formats. Add support for reading binary properties from profiles"}]